# pymadng
Python interface to MAD-NG running as subprocess

Install using below, see [The Python Package Index (PyPi)](https://pypi.org/project/pymadng/);

`pip install pymadng`

Getting the examples working
============================

You can run the example with `python3 EXAMPLE_NAME.py`


Documentation
=============

Documentation, including explanation of a couple of examples and the limitations of the API can be found [here](https://pymadng.readthedocs.io/en/latest/). 

The API reference is also included in [this documentation](https://pymadng.readthedocs.io/en/latest/). You can also compile to documentation yourself by cloning the repository and running ``make html`` in the docs folder.